Can embed scout_action on a separate view of the Scoutbar.
scout_page(label, ..., .list = NULL)A list containing:
children: a sublist where are passed the scout_action.
label: The page label.
class: a character vector to identify the page on the JavaScript side. You are not expected to modify it as it will break the JavaScript binding.
Page label.
Expect scout_action.
To programmatically pass a list of scout_action,
with lapply for instance.
Whenever many scout_action share a similar topic, or have nested topics, this function allows you to provide a better experience by isolating some actions in a separate view. You can nest pages within other pages and combine it with scout_section.